@@ -207,11 +207,18 @@ def connect(state, host):
         # Create new client & connect to the host
         client = SSHClient()
         client.set_missing_host_key_policy(WarningPolicy())
-        client.load_system_host_keys()
+
+        try:
+            client.load_system_host_keys()
+        # Unfortunately paramiko bails for any dodge line in known hosts
+        # See: https://github.com/Fizzadar/pyinfra/issues/683
+        except Exception as e:
+            logger.warning('Failed to load system host keys: {0}'.format(e))
+
         client.connect(hostname, **kwargs)
         return client
 
-    except AuthenticationException:
+    except AuthenticationException as e:
         auth_kwargs = {}
 
         for key, value in kwargs.items():
@@ -227,7 +234,7 @@ def connect(state, host):
             for key, value in auth_kwargs.items()
         )
 
-        _raise_connect_error(host, 'Authentication error', auth_args)
+        _raise_connect_error(host, 'Authentication error ({0})'.format(auth_args), e)
 
     except SSHException as e:
         _raise_connect_error(host, 'SSH error', e)
