@@ -214,13 +214,18 @@ class FindInFile(FactBase):
     lines if the file exists, and ``None`` if the file does not.
     '''
 
-    def command(self, path, pattern):
+    def command(self, path, pattern, interpolate_variables=False):
         self.exists_flag = '__pyinfra_exists_{0}'.format(path)
 
+        if interpolate_variables:
+            pattern = '"{0}"'.format(pattern.replace('"', '\\"'))
+        else:
+            pattern = QuoteString(pattern)
+
         return make_formatted_string_command((
             'grep -e {0} {1} 2> /dev/null || '
             '( find {1} -type f > /dev/null && echo {2} || true )'
-        ), QuoteString(pattern), QuoteString(path), QuoteString(self.exists_flag))
+        ), pattern, QuoteString(path), QuoteString(self.exists_flag))
 
     def process(self, output):
         # If output is the special string: no matches, so return an empty list;
