@@ -205,13 +205,17 @@ def cli(*args, **kwargs):
     pyinfra INVENTORY server.user pyinfra home=/home/pyinfra
 
     \b
-    # Execute an arbitrary command on the inventory
+    # Execute an arbitrary command against the inventory
     pyinfra INVENTORY exec -- echo "hello world"
 
     \b
-    # Run one or more facts on the inventory
+    # Run one or more facts against the inventory
     pyinfra INVENTORY fact server.LinuxName [server.Users]...
     pyinfra INVENTORY fact files.File path=/path/to/file...
+
+    \b
+    # Debug the inventory hosts and data
+    pyinfra INVENTORY debug-inventory
     '''
 
     try:
@@ -470,8 +474,10 @@ def _main(
                     if any(fnmatch(host.name, match) for match in limits)
                 ]
 
-            all_limit_hosts.extend(limit_hosts)
+            if not limit_hosts:
+                logger.warning('No host matches found for --limit pattern: {0}'.format(limiter))
 
+            all_limit_hosts.extend(limit_hosts)
         initial_limit = list(set(all_limit_hosts))
 
     # Initialise the state
